function [cm,msg]=mmgetcommit(branch, key)
% MMGETCOMMIT Get commit message from an item
%
% cm = MMGETCOMMIT(BRANCH, ITEM) gets commit object for ITEM in the branch
% BRANCH.
%
% [cm, msg] = MMGETCOMMIT(BRANCH, ITEM) also return the commit message.
%
% [cm, msg] = MMGETCOMMIT(ITEM) is a little slower than the code above.
%
% Example:
% branch = mmgetbranch('Main', 'Repository 1', 'MyDatabase')
% dat = mmsearch(branch, 'busbar')
% [cm,msg] = mmgetcommit(branch, dat(6))
% % or
% [cm,msg] = mmgetcommit(dat(6))
%
% See also: mmgetcommits, mmsearch, mmgetbranch

narginchk(1,2)

%sig: required, branch, "type=com.comsol.api.database.clientimpl.DatabaseClientApiEndpoints$BranchClient", "Branch object"
%sig: required, key, "struct", "Item"

if nargin==1 && isstruct(branch)
    key = branch.keys.commitkey;
    branch = mmgetbranch(branch);
elseif isstruct(key) && isfield(key, 'keys')
    key = key.keys.commitkey;
end

cm = branch.commitByKey(key);
if nargout>=2
    cmres = cm.get;
    msg.comment = char(cmres.commitComment);
    msg.saved = int64(cmres.saved);
    msg.savedstr = javad2matlabd(cmres.saved);
    msg.savedby = char(cmres.savedBy);
end
