function pd=mphmesh(model,meshtag,varargin)
% MPHMESH Plot a mesh in a MATLAB figure
%
%   MPHMESH(MODEL) plots the model mesh case in a MATLAB figure.
%
%   MPHMESH(MODEL,MESHTAG,...) plots the mesh case with the tag MESHTAG in
%   a MATLAB figure.
%
%   PD = MPHMESH(MODEL,MESHTAG,...) also returns the plot data used in the
%   MATLAB figure in a cell array PD.
%
%   Valid property/value pairs include:
%   Property           Value/{Default}         Description
%   -----------------------------------------------------------------------
%   parent             Axes handle             Parent axis
%   edgecolor          String | Vector | {'k'} Edge color
%   edgelabels         'on'|{'off'}            Show edge labels
%   edgelabelscolor    String | {'k'}          Color for edge labels
%   edgemode           {'on'}|'off'            Show edges
%   facealpha          Double | {1}            Set transparency value
%   facelabels         'on'|{'off'}            Show face labels
%   facelabelscolor    String | Vector | {'k'} Color for face labels
%   facemode           {'on'} | 'off'          Show faces
%   meshcolor          String | Vector         Color for face element (default is gray)
%   vertexcolor        String | Vector | {'k'} Color for vertices
%   vertexlabels       'on' | {'off'}          Show vertex labels
%   vertexlabelscolor  String | {'k'}          Color for vertex labels
%   vertexmode         'on' | {'off'}          Show vertices
%   view               String | {''} |         View settings
%                      'auto'
%
%   Example :
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Create a default mesh:
%     model.mesh.run;
%     % Plot the mesh case
%     mphmesh(model)
%
%     % Create a second mesh case with an "extra fine" default mesh settings:
%     mesh = model.mesh.create('mesh2', 'geom1');
%     mesh.autoMeshSize(2);
%     mesh.run;
%     % Plot the second mesh case with a colored element:
%     mphmesh(model,'mesh2','meshcolor','r');
%
%   See also: mphgeom, mphmeshstats, mphplot

%   Copyright 2010-2023 COMSOL
