function [model,filename]=mphopen(varargin)
% MPHOPEN GUI for opening recent model files
%
%   MPHOPEN starts a GUI with the recent opened files list.
%
%   MPHOPEN -browse DIRPATH starts a GUI with a list of the files in the 
%   specified directory DIRPATH. If DIRPATH is not specified the current 
%   working directory is used.
%
%   MPHOPEN -clear resets the recent opened files list.
%   
%   MODEL = MPHOPEN(FILENAME) loads a COMSOL model object saved with the
%   name FILENAME and assigns the default tag Model in the COMSOL server.
%
%   MODEL = MPHOPEN(FILENAME, MTAG) loads a COMSOL model object and assigns
%   the tag MTAG in the COMSOL server.
%
%   MODEL = MPHOPEN(FILENAME, MTAG, '-nostore') does not update the recent 
%   opened model list.
%
%   MODEL = MPHOPEN(FILENAME, MTAG, '-history') turns on history recording.
%
%   MODEL = MPHOPEN(FILENAME, MTAG, PWD) loads the model in the file 
%   proteced with the password PWD.
%
%   MODEL = MPHOPEN(LOCATION, ...) loads a COMSOL model object saved in 
%   Model Nanager with the location variable LOCATION.
%
%   [MODEL, FILENAMELOADED] = MPHOPEN(FILENAME) also returns the full 
%   file name FILENAMELOADED of the file that is loaded.
%
%   The model tag MTAG and the password PWD must be strings.
%   If the model tag is the same as a model that is currently in the
%   COMSOL server, the loaded model overwrites the existing one, if possible.
%   Note that MATLAB searches for the model on the MATLAB path if an
%   absolute path is not supplied.
%   MPHOPEN turns off the model history recording by default, unless the
%   property '-history' is used.
%   The extension 'mph' can be omitted.
%
%   See also: mphload, mphsave

%   Copyright 2010-2023 COMSOL
