function n=mphselectball(model,geomtag,coord,entity,varargin)
% MPHSELECTBALL Select geometric entity using a ball selection
%
% N = MPHSELECTBALL(MODEL,GEOMTAG,COORD,ENTITY,...) finds geometry
% entity numbers that are inside a ball defined by its coordinates
% and radius.
%
% GEOMTAG is the geometry tag of the geometry where the search should
% be performed.
%
% COORD is a column vector with the coordinates of the sphere.
%
% ENTITY can be one of 'point', 'edge', 'boundary' or 'domain'.
%
% Valid property/value pairs include:
% Property     Value/{Default}            Description
% -----------------------------------------------------------------------
% include      {intersects} | inside |    Condition for including 
%              boundary | domain          geometry entities
% radius       Scalar {1}                 Radius of the sphere
%
% Example 1: Find entity numbers of points near (0,0,0.01)
% model = mphopen('model_tutorial_llmatlab');
% coord = [0 0 0.01];
% n = mphselectball(model,'geom1',coord','point','radius',0.001)
% mphviewselection(model,'geom1',n,'point')
%
% Example 2: Find entity numbers of suefaces inside a sphere near (0,0,0.01)
% model = mphopen('model_tutorial_llmatlab');
% coord = [0 0 0.01];
% n = mphselectball(model,'geom1',coord','boundary','radius',0.02,'include','inside')
% mphviewselection(model,'geom1',n,'boundary')
%
% See also: mphgetadj, mphgetcoords, mphselectbox, mphviewselection

%   Copyright 2010-2023 COMSOL
