function mphsetparam(node,varargin)
% MPHSETPARAM Set parameter values
%
% Set parameter values using name/value pairs or by supplying values as
% cell arrays, strucst or dictionaries.
%
% % Example 1:
% % Set value in model.param
% mphsetparam(model, 'L', '9[cm]')
% % Also set description
% mphsetparam(model, 'L', '9[cm]', 'Length')
% % Remove 'L' by setting it to an empty matrix
% mphsetparam(model, 'L', [])
%
% % Example 2:
% cellarray = {'L' '9[cm]' 'wb' 0.09};
% mphsetparam(model, cellarray)
%
% % Example 3:
% param.L = '9[cm]';
% param.wb = 0.05;
% param.complex = 1+2i;
% mphsetparam(model, param)
%
% % Example 4:
% d = dictionary;
% d("L") = 0.09;
% d("wb") = 0.06;
% mphsetparam(model, d)
%
% Example 5: Parameter groups
% mphsetparam(model, 'group1/L', '10[cm]')
%
% Example 6: Parameter cases
% mphsetparam(model, 'group/case1/L', '10[cm]')
% mphsetparam(model, 'group/case2/L', '12[cm]')
%
% See also: mphevaluate, mphgetexpressions

%   Copyright 2010-2023 COMSOL
